==> nextcloud-22.2.9.tgz: nextcloud/apps/user_status/l10n/fa.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "وضعیت های اخیر",
    "In a meeting" : "در جلسه",
    "Commuting" : "در رفت و آمد",
    "Out sick" : "مرخصی استعلاجی",
    "Vacationing" : "تعطیلات",
    "Working remotely" : "دورکاری",
    "In a call" : "در حال تماس تلفنی",
    "User status" : "وضعبت کاربر",
    "View profile" : "مشاهده پروفایل",
    "Clear status after" : "پاک کردن وضعیت بعدی",
    "What is your status?" : "وضعیت شما چیست؟",
    "Set status" : "تنظیم وضعیت",
    "Online status" : "وضعیت آنلاین",
    "Status message" : "پیغام وضعیت",
    "Clear status message" : "پیام وضعیت را پاک کن",
    "Set status message" : "تنظیم پیام وضعیت",
    "There was an error saving the status" : "مشکلی در ذخیره سازی وضعیت پیش آمده",
    "There was an error clearing the status" : "مشکلی در پاک کردن وضعیت پیش آمده",
    "No recent status changes" : "هیچ تغییر وضعیت جدیدی وجود ندارد",
    "Away" : "دور",
    "Do not disturb" : "مزاحم نشوید",
    "Don't clear" : "پاک نکن",
    "Today" : "Today",
    "This week" : "این هفته",
    "Online" : "آنلاین",
    "Invisible" : "نامرئی",
    "Offline" : "آفلاین",
    "There was an error saving the new status" : "مشکلی در ذخیره سازی وضعیت جدید پیش آمده",
    "30 minutes" : "۳۰ دقیقه",
    "1 hour" : "1 ساعت",
    "4 hours" : "۴ ساعت",
    "Mute all notifications" : "خاموش کردن همه اعلانات",
    "Appear offline" : "نمایش آفلاین",
    "Clear status message after" : "بعد از آن پیام وضعیت را پاک کن ",
    "What's your status?" : "وضعیت شما چیست؟"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-23.0.7.tgz: nextcloud/apps/user_status/l10n/fa.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "وضعیت های اخیر",
    "In a meeting" : "در جلسه",
    "Commuting" : "در رفت و آمد",
    "Out sick" : "مرخصی استعلاجی",
    "Vacationing" : "تعطیلات",
    "Working remotely" : "دورکاری",
    "In a call" : "در حال تماس تلفنی",
    "User status" : "وضعبت کاربر",
    "View profile" : "مشاهده پروفایل",
    "Clear status after" : "پاک کردن وضعیت بعدی",
    "What is your status?" : "وضعیت شما چیست؟",
    "Set status" : "تنظیم وضعیت",
    "Online status" : "وضعیت آنلاین",
    "Status message" : "پیغام وضعیت",
    "Clear status message" : "پیام وضعیت را پاک کن",
    "Set status message" : "تنظیم پیام وضعیت",
    "There was an error saving the status" : "مشکلی در ذخیره سازی وضعیت پیش آمده",
    "There was an error clearing the status" : "مشکلی در پاک کردن وضعیت پیش آمده",
    "No recent status changes" : "هیچ تغییر وضعیت جدیدی وجود ندارد",
    "Away" : "بیرون",
    "Do not disturb" : "مزاحم نشوید",
    "Don't clear" : "پاک نکن",
    "Today" : "امروز",
    "This week" : "این هفته",
    "Online" : "آنلاین",
    "Invisible" : "غیر قابل مشاهده",
    "Offline" : "آفلاین",
    "There was an error saving the new status" : "مشکلی در ذخیره سازی وضعیت جدید پیش آمده",
    "30 minutes" : "۳۰ دقیقه",
    "1 hour" : "۱ ساعت",
    "4 hours" : "۴ ساعت",
    "Mute all notifications" : "خاموش کردن همه اعلانات",
    "Appear offline" : "نمایش آفلاین",
    "Clear status message after" : "پاک کردن پیام وضعیت بعد از",
    "What's your status?" : "وضعیت شما چیست؟"
},
"nplurals=2; plural=(n > 1);");
